@@ -215,7 +215,7 @@ class VtkRemoteLocalView(AbstractElement):
         # Provide mandatory attributes
         self._attributes["wsClient"] = ':wsClient="wsClient"'
         self._attributes["ref"] = f'ref="{self.__ref}"'
-        self._attributes["view_id"] = f':id="{self.__view_key_id}"'
+        self._attributes["view_id"] = f':viewId="{self.__view_key_id}"'
         self._attributes["view_state"] = f':viewState="{self.__scene_id}"'
         self._attributes["namespace"] = f'namespace="{__ns}"'
 
@@ -317,7 +317,7 @@ class VtkRemoteView(AbstractElement):
         state[self.__view_key_id] = MODULE.id(view)
         self._attributes["wsClient"] = ':wsClient="wsClient"'
         self._attributes["ref"] = f'ref="{ref}"'
-        self._attributes["view_id"] = f':id="{self.__view_key_id}"'
+        self._attributes["view_id"] = f':viewId="{self.__view_key_id}"'
         self._attr_names += [
             "enable_picking",
             "interactive_quality",
